# frozen_string_literal: true

require "rails_helper"

RSpec.describe MrCommon::Registrations::PublicController, type: :controller do
  describe "#create" do
    it "renders the host new registration template on failure" do
      post :create, params: { registration: { first_name: "" } }
      expect(response.status).to eq 422
    end

    it "redirects to the default success path" do
      registration_params = attributes_for(:registration)
      post :create, params: { registration: registration_params }
      expect(response).to redirect_to registrations_success_index_path
    end

    it "creates a registration record" do
      count = MrCommon::Registration.count
      registration_params = attributes_for(:registration)
      post :create, params: { registration: registration_params }
      difference = MrCommon::Registration.count - count
      expect(difference).to eq 1
    end
  end
end
